@@ -1,6 +1,6 @@
-package plenigo::Meta;
+package plenigo;
 
-our $VERSION = 0.200;
+our $VERSION = '2.0000';
 
 =head1 NAME
 
